@@ -64,7 +64,6 @@
 /* Signals */
 enum {
 	HIGHLIGHT_UPDATED,
-	MARKER_UPDATED,
 	LAST_SIGNAL
 };
 
@@ -89,8 +88,6 @@ struct _GtkSourceBufferPrivate
 	GtkTextMark           *bracket_mark;
 	guint                  bracket_found:1;
 
-	GArray                *markers;
-
 	GtkSourceLanguage     *language;
 
 	GtkSourceEngine       *highlight_engine;
@@ -256,16 +253,6 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 			   G_TYPE_NONE,
 			   2, param_types);
 
-	buffer_signals[MARKER_UPDATED] =
-	    g_signal_newv ("marker_updated",
-			   G_OBJECT_CLASS_TYPE (object_class),
-			   G_SIGNAL_RUN_LAST,
-			   NULL,
-			   NULL, NULL,
-			   _gtksourceview_marshal_VOID__BOXED,
-			   G_TYPE_NONE,
-			   1, param_types);
-
 	g_type_class_add_private (object_class, sizeof(GtkSourceBufferPrivate));
 }
 
@@ -286,8 +273,6 @@ gtk_source_buffer_init (GtkSourceBuffer *buffer)
 	priv->bracket_mark = NULL;
 	priv->bracket_found = FALSE;
 
-	priv->markers = g_array_new (FALSE, FALSE, sizeof (GtkSourceMarker *));
-
 	priv->style_scheme = _gtk_source_style_scheme_get_default ();
 	if (priv->style_scheme != NULL)
 		g_object_ref (priv->style_scheme);
@@ -317,9 +302,6 @@ gtk_source_buffer_finalize (GObject *object)
 	buffer = GTK_SOURCE_BUFFER (object);
 	g_return_if_fail (buffer->priv != NULL);
 
-	if (buffer->priv->markers)
-		g_array_free (buffer->priv->markers, TRUE);
-
 	G_OBJECT_CLASS (gtk_source_buffer_parent_class)->finalize (object);
 }
 
@@ -653,7 +635,6 @@ gtk_source_buffer_real_delete_range (GtkTextBuffer *buffer,
 	gint offset, length;
 	GtkTextMark *mark;
 	GtkTextIter iter;
-	GSList *markers;
 	GtkSourceBuffer *source_buffer = GTK_SOURCE_BUFFER (buffer);
 
 	g_return_if_fail (GTK_IS_SOURCE_BUFFER (buffer));
@@ -666,18 +647,6 @@ gtk_source_buffer_real_delete_range (GtkTextBuffer *buffer,
 	offset = gtk_text_iter_get_offset (start);
 	length = gtk_text_iter_get_offset (end) - offset;
 
-	/* remove the markers in the deleted region if deleting more than one character */
-	if (length > 1)
-	{
-		markers = gtk_source_buffer_get_markers_in_region (GTK_SOURCE_BUFFER (buffer),
-								   start, end);
-		while (markers)
-		{
-			gtk_source_buffer_delete_marker (GTK_SOURCE_BUFFER (buffer), markers->data);
-			markers = g_slist_delete_link (markers, markers);
-		}
-	}
-
 	GTK_TEXT_BUFFER_CLASS(gtk_source_buffer_parent_class)->delete_range (buffer, start, end);
 
 	mark = gtk_text_buffer_get_insert (buffer);
@@ -688,25 +657,6 @@ gtk_source_buffer_real_delete_range (GtkTextBuffer *buffer,
 				       mark,
 				       NULL);
 
-	/* move any markers which moved to this line because of the
-	 * deletion to the beginning of the line */
-	iter = *start;
-	if (!gtk_text_iter_ends_line (&iter))
-		gtk_text_iter_forward_to_line_end (&iter);
-	markers = gtk_source_buffer_get_markers_in_region (GTK_SOURCE_BUFFER (buffer),
-							   start, &iter);
-	if (markers)
-	{
-		GSList *m;
-
-		gtk_text_iter_set_line_offset (&iter, 0);
-		for (m = markers; m; m = g_slist_next (m))
-			gtk_source_buffer_move_marker (GTK_SOURCE_BUFFER (buffer),
-						       GTK_SOURCE_MARKER (m->data),
-						       &iter);
-		g_slist_free (markers);
-	}
-
 	/* emit text deleted for engines */
 	if (source_buffer->priv->highlight_engine != NULL)
 		_gtk_source_engine_text_deleted (source_buffer->priv->highlight_engine,
@@ -1306,689 +1256,3 @@ gtk_source_buffer_get_style_scheme (GtkSourceBuffer *buffer)
 	return buffer->priv->style_scheme;
 }
 
-/* Markers functionality */
-
-/**
- * markers_binary_search:
- * @buffer: the GtkSourceBuffer where the markers are.
- * @iter: the position to search for.
- * @last_cmp: where to return the value of the last comparision made (optional).
- *
- * Performs a binary search among the markers in @buffer for the
- * position of the @iter.  Returns the nearest matching marker (its
- * index in the markers array) and optionally the value of the
- * comparision between the returned marker and the given iter.
- *
- * Return value: an index in the markers array or -1 if the array is
- * empty.
- **/
-static gint
-markers_binary_search (GtkSourceBuffer *buffer, GtkTextIter *iter, gint *last_cmp)
-{
-	GtkTextIter check_iter;
-	GtkSourceMarker **check, **p;
-	GArray *markers = buffer->priv->markers;
-	gint n_markers = markers->len;
-	gint cmp, i;
-
-	if (n_markers == 0)
-		return -1;
-
-	check = p = &g_array_index (markers, GtkSourceMarker *, 0);
-	p--;
-	cmp = 0;
-	while (n_markers)
-	{
-		i = (n_markers + 1) >> 1;
-		check = p + i;
-		gtk_text_buffer_get_iter_at_mark (GTK_TEXT_BUFFER (buffer),
-						  &check_iter,
-						  GTK_TEXT_MARK (*check));
-		cmp = gtk_text_iter_compare (iter, &check_iter);
-		if (cmp > 0)
-		{
-			n_markers -= i;
-			p = check;
-		}
-		else if (cmp < 0)
-			n_markers = i - 1;
-		else /* if (cmp == 0) */
-			break;
-	}
-
-	i = check - &g_array_index (markers, GtkSourceMarker *, 0);
-	if (last_cmp)
-		*last_cmp = cmp;
-
-	return i;
-}
-
-/**
- * markers_linear_lookup:
- * @buffer: the source buffer where the markers are.
- * @marker: which marker to search for.
- * @start: index from where to start looking.
- * @direction: direction to search for.
- *
- * Searches the markers array of @buffer starting from @start for
- * markers at the same position as the one at @start.  If @marker is
- * non-%NULL search for that marker specifically, otherwise return the
- * first or the last marker at the staring position, depending on
- * @direction.
- *
- * @direction < 0 means left, @direction > 0 means right,
- * 0 means both and is mostly useful when looking for a specific
- * @marker.
- *
- * Return value: the index of the searched marker.
- **/
-static gint
-markers_linear_lookup (GtkSourceBuffer *buffer,
-		       GtkSourceMarker *marker,
-		       gint             start,
-		       gint             direction)
-{
-	GArray *markers = buffer->priv->markers;
-	gint left, right;
-	gint cmp;
-	GtkTextIter iter;
-	GtkSourceMarker *tmp;
-
-	tmp = g_array_index (markers, GtkSourceMarker *, start);
-	if (tmp == marker)
-		return start;
-
-	gtk_text_buffer_get_iter_at_mark (GTK_TEXT_BUFFER (buffer),
-					  &iter,
-					  GTK_TEXT_MARK (tmp));
-
-	if (direction == 0)
-	{
-		left = start - 1;
-		right = start + 1;
-	}
-	else if (direction > 0)
-	{
-		left = -1;
-		right = start + 1;
-	}
-	else
-	{
-		left = start - 1;
-		right = markers->len;
-	}
-
-	while (left >= 0 || right < markers->len)
-	{
-		GtkTextIter iter_tmp;
-
-		if (left >= 0)
-		{
-			tmp = g_array_index (markers, GtkSourceMarker *, left);
-			if (tmp == marker)
-				return left;
-
-			gtk_text_buffer_get_iter_at_mark (GTK_TEXT_BUFFER (buffer),
-							  &iter_tmp,
-							  GTK_TEXT_MARK (tmp));
-			cmp = gtk_text_iter_compare (&iter, &iter_tmp);
-			if (cmp != 0)
-			{
-				if (marker)
-					/* searching for a particular marker */
-					left = -1;
-				else
-					/* searching for the first
-					 * marker at a given
-					 * position */
-					return left + 1;
-			} else
-				left--;
-		}
-
-		if (right < markers->len)
-		{
-			tmp = g_array_index (markers, GtkSourceMarker *, right);
-			if (tmp == marker)
-				return right;
-
-			gtk_text_buffer_get_iter_at_mark (GTK_TEXT_BUFFER (buffer),
-							  &iter_tmp,
-							  GTK_TEXT_MARK (tmp));
-			cmp = gtk_text_iter_compare (&iter, &iter_tmp);
-			if (cmp != 0)
-			{
-				if (marker)
-					/* searching for a particular marker */
-					right = markers->len;
-				else
-					/* searching for the last
-					 * marker at a given
-					 * position */
-					return right - 1;
-			}
-			else
-				right++;
-		}
-	}
-	if (marker)
-		return -1;
-	else
-		return start;
-}
-
-static void
-markers_insert (GtkSourceBuffer *buffer, GtkSourceMarker *marker)
-{
-	GtkTextIter iter;
-	gint index, cmp;
-
-	gtk_text_buffer_get_iter_at_mark (GTK_TEXT_BUFFER (buffer),
-					  &iter,
-					  GTK_TEXT_MARK (marker));
-
-	index = markers_binary_search (buffer, &iter, &cmp);
-	if (index >= 0)
-	{
-		_gtk_source_marker_link (marker, g_array_index (buffer->priv->markers,
-								GtkSourceMarker *,
-								index),	(cmp > 0));
-		if (cmp > 0)
-			index++;
-	}
-	else
-		index = 0;
-
-	g_array_insert_val (buffer->priv->markers, index, marker);
-}
-
-/**
- * gtk_source_buffer_create_marker:
- * @buffer: a #GtkSourceBuffer.
- * @name: the name of the marker, or %NULL.
- * @type: a string defining the marker type, or %NULL.
- * @where: location to place the marker.
- *
- * Creates a marker in the @buffer of type @type.  A marker is
- * semantically very similar to a #GtkTextMark, except it has a type
- * which is used by the #GtkSourceView displaying the buffer to show a
- * pixmap on the left margin, at the line the marker is in.  Because
- * of this, a marker is generally associated to a line and not a
- * character position.  Markers are also accessible through a position
- * or range in the buffer.
- *
- * Markers are implemented using #GtkTextMark, so all characteristics
- * and restrictions to marks apply to markers too.  These includes
- * life cycle issues and "mark-set" and "mark-deleted" signal
- * emissions.
- *
- * Like a #GtkTextMark, a #GtkSourceMarker can be anonymous if the
- * passed @name is %NULL.  Also, the buffer owns the markers so you
- * shouldn't unreference it.
- *
- * Markers always have left gravity and are moved to the beginning of
- * the line when the user deletes the line they were in.  Also, if the
- * user deletes a region of text which contained lines with markers,
- * those are deleted.
- *
- * Typical uses for a marker are bookmarks, breakpoints, current
- * executing instruction indication in a source file, etc..
- *
- * Return value: a new #GtkSourceMarker, owned by the buffer.
- **/
-GtkSourceMarker *
-gtk_source_buffer_create_marker (GtkSourceBuffer   *buffer,
-				 const gchar       *name,
-				 const gchar       *type,
-				 const GtkTextIter *where)
-{
-	GtkTextMark *text_mark;
-
-	g_return_val_if_fail (buffer != NULL, NULL);
-	g_return_val_if_fail (GTK_IS_SOURCE_BUFFER (buffer), NULL);
-	g_return_val_if_fail (where != NULL, NULL);
-
-	text_mark = gtk_text_buffer_create_mark (GTK_TEXT_BUFFER (buffer),
-						 name,
-						 where,
-						 TRUE);
-	if (text_mark)
-	{
-		g_object_ref (text_mark);
-
-		gtk_source_marker_set_marker_type (GTK_SOURCE_MARKER (text_mark), type);
-		markers_insert (buffer, GTK_SOURCE_MARKER (text_mark));
-		_gtk_source_marker_changed (GTK_SOURCE_MARKER (text_mark));
-
-		return GTK_SOURCE_MARKER (text_mark);
-	}
-
-	return NULL;
-}
-
-static gint
-markers_lookup (GtkSourceBuffer *buffer, GtkSourceMarker *marker)
-{
-	gint index, cmp;
-	GtkTextIter iter;
-
-	gtk_text_buffer_get_iter_at_mark (GTK_TEXT_BUFFER (buffer),
-					  &iter,
-					  GTK_TEXT_MARK (marker));
-
-	index = markers_binary_search (buffer, &iter, &cmp);
-	if (index >= 0 && cmp == 0)
-	{
-		if (g_array_index (buffer->priv->markers,
-				   GtkSourceMarker *,
-				   index) == marker)
-			return index;
-		return markers_linear_lookup (buffer, marker, index, 0);
-	}
-	return -1;
-}
-
-/**
- * gtk_source_buffer_move_marker:
- * @buffer: a #GtkSourceBuffer.
- * @marker: a #GtkSourceMarker in @buffer.
- * @where: the new location for the marker.
- *
- * Moves @marker to the new location @where.
- **/
-void
-gtk_source_buffer_move_marker (GtkSourceBuffer   *buffer,
-			       GtkSourceMarker   *marker,
-			       const GtkTextIter *where)
-{
-	gint index;
-
-	g_return_if_fail (buffer != NULL && marker != NULL);
-	g_return_if_fail (GTK_IS_SOURCE_BUFFER (buffer));
-	g_return_if_fail (GTK_IS_SOURCE_MARKER (marker));
-	g_return_if_fail (!gtk_text_mark_get_deleted (GTK_TEXT_MARK (marker)));
-	g_return_if_fail (where != NULL);
-
-	index = markers_lookup (buffer, marker);
-
-	g_return_if_fail (index >= 0);
-
-	/* unlink the marker first */
-	_gtk_source_marker_changed (marker);
-	_gtk_source_marker_unlink (marker);
-	g_array_remove_index (buffer->priv->markers, index);
-
-	gtk_text_buffer_move_mark (GTK_TEXT_BUFFER (buffer),
-				   GTK_TEXT_MARK (marker),
-				   where);
-
-	/* re-link the marker using the new position */
-	markers_insert (buffer, marker);
-
-	/* FIXME: emit even the line number hasn't changed? - Gustavo */
-	_gtk_source_marker_changed (marker);
-}
-
-/**
- * gtk_source_buffer_delete_marker:
- * @buffer: a #GtkSourceBuffer.
- * @marker: a #GtkSourceMarker in the @buffer.
- *
- * Deletes @marker from the source buffer.  The same conditions as for
- * #GtkTextMark apply here.  The marker is no longer accessible from
- * the buffer, but if you held a reference to it, it will not be
- * destroyed.
- **/
-void
-gtk_source_buffer_delete_marker (GtkSourceBuffer *buffer,
-				 GtkSourceMarker *marker)
-{
-	gint index;
-
-	g_return_if_fail (buffer != NULL && marker != NULL);
-	g_return_if_fail (GTK_IS_SOURCE_BUFFER (buffer));
-	g_return_if_fail (GTK_IS_SOURCE_MARKER (marker));
-	g_return_if_fail (!gtk_text_mark_get_deleted (GTK_TEXT_MARK (marker)));
-
-	index = markers_lookup (buffer, marker);
-
-	g_return_if_fail (index >= 0);
-
-	_gtk_source_marker_changed (marker);
-	_gtk_source_marker_unlink (marker);
-	g_array_remove_index (buffer->priv->markers, index);
-
-	g_object_unref (marker);
-	gtk_text_buffer_delete_mark (GTK_TEXT_BUFFER (buffer),
-				     GTK_TEXT_MARK (marker));
-}
-
-/**
- * gtk_source_buffer_get_marker:
- * @buffer: a #GtkSourceBuffer.
- * @name: name of the marker to retrieve.
- *
- * Looks up the #GtkSourceMarker named @name in @buffer, returning
- * %NULL if it doesn't exists.
- *
- * Return value: the #GtkSourceMarker whose name is @name, or %NULL.
- **/
-GtkSourceMarker *
-gtk_source_buffer_get_marker (GtkSourceBuffer *buffer,
-			      const gchar     *name)
-{
-	GtkTextMark *text_mark;
-
-	g_return_val_if_fail (buffer != NULL, NULL);
-	g_return_val_if_fail (GTK_IS_SOURCE_BUFFER (buffer), NULL);
-	g_return_val_if_fail (name != NULL, NULL);
-
-	text_mark = gtk_text_buffer_get_mark (GTK_TEXT_BUFFER (buffer), name);
-
-	if (text_mark && markers_lookup (buffer, GTK_SOURCE_MARKER (text_mark)) < 0)
-		text_mark = NULL;
-
-	if (text_mark)
-		return GTK_SOURCE_MARKER (text_mark);
-	else
-		return NULL;
-}
-
-#ifdef ENABLE_DEBUG
-static void
-marker_print (GtkSourceBuffer *buffer, GtkSourceMarker *marker)
-{
-	GtkTextIter iter;
-	gchar *type;
-
-	type = gtk_source_marker_get_marker_type (marker);
-	gtk_text_buffer_get_iter_at_mark (GTK_TEXT_BUFFER (buffer), &iter, marker);
-
-	g_print ("Marker [%p] at %d (type: %s)\n",
-		 marker,
-		 gtk_text_iter_get_offset (&iter),
-		 type);
-	g_free (type);
-}
-
-static void
-markers_debug (GtkSourceBuffer *buffer)
-{
-	GtkSourceMarker *marker, *tmp;
-	GArray *markers = buffer->priv->markers;
-	gint i;
-
-	if (markers->len == 0)
-	{
-		g_print ("No markers\n");
-		return;
-	}
-
-	g_print ("Array contents:\n");
-	for (i = 0; i < markers->len; i++)
-		marker_print (buffer, g_array_index (markers, GtkSourceMarker *, i));
-
-	g_print ("Linked list:\n");
-	marker = g_array_index (markers, GtkSourceMarker *, 0);
-
-	while ((tmp = gtk_source_marker_prev (marker)) != NULL)
-		marker = tmp;
-	while (marker)
-	{
-		marker_print (buffer, marker);
-		marker = gtk_source_marker_next (marker);
-	}
-}
-#endif
-
-/**
- * gtk_source_buffer_get_markers_in_region:
- * @buffer: a #GtkSourceBuffer.
- * @begin: beginning of the range.
- * @end: end of the range.
- *
- * Returns an <emphasis>ordered</emphasis> (by position) #GSList of
- * #GtkSourceMarker objects inside the region delimited by the
- * #GtkTextIter @begin and @end.  The iters may be in any order.
- *
- * Return value: a #GSList of the #GtkSourceMarker inside the range.
- **/
-GSList *
-gtk_source_buffer_get_markers_in_region (GtkSourceBuffer   *buffer,
-					 const GtkTextIter *begin,
-					 const GtkTextIter *end)
-{
-	GSList *result;
-	GtkTextIter iter1, iter2;
-	gint i, j, cmp;
-	GArray *markers;
-
-	g_return_val_if_fail (buffer != NULL, NULL);
-	g_return_val_if_fail (GTK_IS_SOURCE_BUFFER (buffer), NULL);
-	g_return_val_if_fail (begin != NULL && end != NULL, NULL);
-
-	DEBUG (g_print ("Getting markers for [%d,%d]\n",
-			gtk_text_iter_get_offset (begin),
-			gtk_text_iter_get_offset (end)));
-	DEBUG (markers_debug (buffer));
-
-	iter1 = *begin;
-	iter2 = *end;
-	gtk_text_iter_order (&iter1, &iter2);
-
-	result = NULL;
-	markers = buffer->priv->markers;
-
-	i = markers_binary_search (buffer, &iter1, &cmp);
-	if (i < 0)
-		return NULL;
-
-	if (cmp == 0)
-		/* we got an exact match, which means the iter was at
-		 * the position of the returned marker.  now we have
-		 * to search backward for other markers at the same
-		 * position */
-		i = markers_linear_lookup (buffer, NULL, i, -1);
-	else if (cmp > 0)
-		i++;
-
-	if (i >= markers->len)
-		/* no markers to return */
-		return NULL;
-
-	j = markers_binary_search (buffer, &iter2, &cmp);
-	if (cmp == 0)
-		/* we got an exact match, which means the iter was at
-		 * the position of the returned marker.  now we have
-		 * to search forward for other markers at the same
-		 * position */
-		j = markers_linear_lookup (buffer, NULL, j, 1);
-	else if (cmp < 0)
-		j--;
-
-	if (j < 0 || i > j)
-		/* no markers to return */
-		return NULL;
-
-	/* build the resulting list */
-	while (j >= i)
-	{
-		result = g_slist_prepend (result, g_array_index (markers, GtkSourceMarker *, j));
-		j--;
-	}
-
-	DEBUG({
-		GSList *l;
-
-		g_print ("Returned list:\n");
-		for (l = result; l; l = l->next)
-			marker_print (buffer, l->data);
-	});
-
-	return result;
-}
-
-/**
- * gtk_source_buffer_get_first_marker:
- * @buffer: a #GtkSourceBuffer.
- *
- * Returns the first (nearest to the top of the buffer) marker in
- * @buffer.
- *
- * Return value: a reference to the first #GtkSourceMarker, or %NULL if
- * there are no markers in the buffer.
- **/
-GtkSourceMarker *
-gtk_source_buffer_get_first_marker (GtkSourceBuffer *buffer)
-{
-	g_return_val_if_fail (buffer != NULL, NULL);
-	g_return_val_if_fail (GTK_IS_SOURCE_BUFFER (buffer), NULL);
-
-	if (buffer->priv->markers->len == 0)
-		return NULL;
-
-	return g_array_index (buffer->priv->markers, GtkSourceMarker *, 0);
-}
-
-/**
- * gtk_source_buffer_get_last_marker:
- * @buffer: a #GtkSourceBuffer.
- *
- * Returns the last (nearest to the bottom of the buffer) marker in
- * @buffer.
- *
- * Return value: a reference to the last #GtkSourceMarker, or %NULL if
- * there are no markers in the buffer.
- **/
-GtkSourceMarker *
-gtk_source_buffer_get_last_marker (GtkSourceBuffer *buffer)
-{
-	g_return_val_if_fail (buffer != NULL, NULL);
-	g_return_val_if_fail (GTK_IS_SOURCE_BUFFER (buffer), NULL);
-
-	if (buffer->priv->markers->len == 0)
-		return NULL;
-
-	return g_array_index (buffer->priv->markers,
-			      GtkSourceMarker *,
-			      buffer->priv->markers->len - 1);
-}
-
-/**
- * gtk_source_buffer_get_iter_at_marker:
- * @buffer: a #GtkSourceBuffer.
- * @iter: a #GtkTextIter to initialize.
- * @marker: a #GtkSourceMarker of @buffer.
- *
- * Initializes @iter at the location of @marker.
- **/
-void
-gtk_source_buffer_get_iter_at_marker (GtkSourceBuffer *buffer,
-				      GtkTextIter     *iter,
-				      GtkSourceMarker *marker)
-{
-	g_return_if_fail (buffer != NULL && marker != NULL);
-	g_return_if_fail (GTK_IS_SOURCE_BUFFER (buffer));
-	g_return_if_fail (GTK_IS_SOURCE_MARKER (marker));
-	g_return_if_fail (!gtk_text_mark_get_deleted (GTK_TEXT_MARK (marker)));
-
-	gtk_text_buffer_get_iter_at_mark (GTK_TEXT_BUFFER (buffer),
-					  iter,
-					  GTK_TEXT_MARK (marker));
-}
-
-/**
- * gtk_source_buffer_get_next_marker:
- * @buffer: a #GtkSourceBuffer.
- * @iter: the location to start searching from.
- *
- * Returns the nearest marker to the right of @iter.  If there are
- * multiple markers at the same position, this function will always
- * return the first one (from the internal linked list), even if
- * starting the search exactly at its location.  You can get the
- * others using gtk_source_marker_next().
- *
- * Return value: the #GtkSourceMarker nearest to the right of @iter,
- * or %NULL if there are no more markers after @iter.
- **/
-GtkSourceMarker *
-gtk_source_buffer_get_next_marker (GtkSourceBuffer *buffer,
-				   GtkTextIter     *iter)
-{
-	GtkSourceMarker *marker;
-	GArray *markers;
-	gint i, cmp;
-
-	g_return_val_if_fail (buffer != NULL, NULL);
-	g_return_val_if_fail (GTK_IS_SOURCE_BUFFER (buffer), NULL);
-	g_return_val_if_fail (iter != NULL, NULL);
-
-	marker = NULL;
-	markers = buffer->priv->markers;
-
-	i = markers_binary_search (buffer, iter, &cmp);
-	if (i < 0)
-		return NULL;
-
-	if (cmp == 0)
-		/* return the first marker at the iter position */
-		i = markers_linear_lookup (buffer, NULL, i, -1);
-	else if (cmp > 0)
-		i++;
-
-	if (i < markers->len)
-	{
-		marker = g_array_index (markers, GtkSourceMarker *, i);
-		gtk_source_buffer_get_iter_at_marker (buffer, iter, marker);
-	}
-
-	return marker;
-}
-
-/**
- * gtk_source_buffer_get_prev_marker:
- * @buffer: a #GtkSourceBuffer.
- * @iter: the location to start searching from.
- *
- * Returns the nearest marker to the left of @iter.  If there are
- * multiple markers at the same position, this function will always
- * return the last one (from the internal linked list), even if
- * starting the search exactly at its location.  You can get the
- * others using gtk_source_marker_prev().
- *
- * Return value: the #GtkSourceMarker nearest to the left of @iter,
- * or %NULL if there are no more markers before @iter.
- **/
-GtkSourceMarker *
-gtk_source_buffer_get_prev_marker (GtkSourceBuffer *buffer,
-				   GtkTextIter     *iter)
-{
-	GtkSourceMarker *marker;
-	GArray *markers;
-	gint i, cmp;
-
-	g_return_val_if_fail (buffer != NULL, NULL);
-	g_return_val_if_fail (GTK_IS_SOURCE_BUFFER (buffer), NULL);
-	g_return_val_if_fail (iter != NULL, NULL);
-
-	marker = NULL;
-	markers = buffer->priv->markers;
-
-	i = markers_binary_search (buffer, iter, &cmp);
-	if (i < 0)
-		return NULL;
-
-	if (cmp == 0)
-		/* return the last marker at the iter position */
-		i = markers_linear_lookup (buffer, NULL, i, 1);
-	else if (cmp < 0)
-		i--;
-
-	if (i >= 0)
-	{
-		marker = g_array_index (markers, GtkSourceMarker *, i);
-		gtk_source_buffer_get_iter_at_marker (buffer, iter, marker);
-	}
-
-	return marker;
-}
